@@ -70,13 +70,13 @@ class Spec:
             if issubclass(cls, Node) and cls is not Node:
                 node = {}
                 inst = cls()
-                node.id = inst.name
-                node.name = inst.title
-                node.icon = inst.icon
-                node.color = inst.color
-                node.editor = inst.editor
-                node.inputs = inst.inputs
-                node.outputs = inst.outputs
+                node['id'] = inst.name
+                node['name'] = inst.title
+                node['icon'] = inst.icon
+                node['color'] = inst.color
+                node['editor'] = inst.editor
+                node['inputs'] = inst.inputs
+                node['outputs'] = inst.outputs
 
                 properties = []
                 inputVars = Spec.get_inputs_vars(cls)
